# Orthojax - Polynomial Chaos in Jax

This is an Python implementation of some of the functions in the
`orthpol`` package by Walter Gautschi. The original Fortran code can be
found [here](http://www.cs.purdue.edu/archives/2002/wxg/codes/orthpol.f).


## Examples

- You can learn more about how the package works [here](https://predictivesciencelab.github.io/advanced-scientific-machine-learning/polynomial_chaos/04_orthpol_demo.html).
- You can find an example to uncertainty propagation [here](https://predictivesciencelab.github.io/advanced-scientific-machine-learning/polynomial_chaos/05_pc_ode_1d.html). 

## Todo

- Add tensor product support.